@@ -25,6 +25,16 @@
 #include "http_request.h" 
 #include "util_script.h" 
 #include "http_conf_globals.h"
+#ifdef APACHE_SSL
+#undef _
+#ifdef _config_h_
+#ifdef CAN_PROTOTYPE
+#define _(args) args
+#else
+#define _(args) ()
+#endif
+#endif
+#endif
 #endif
 
 #include "EXTERN.h"
@@ -34,6 +44,22 @@
 #endif
 #include "XSUB.h"
 
+
+/* patchlevel.h causes a -Wall warning, 
+ * plus chance that another patchlevel.h might be in -I paths
+ * so try to avoid it if possible 
+ */ 
+#ifdef PERL_VERSION
+#if PERL_VERSION >= 500476
+#include "perl_PL.h"
+#endif
+#else
+#include "patchlevel.h"
+#if ((PATCHLEVEL >= 4) && (SUBVERSION >= 76)) || (PATCHLEVEL >= 5)
+#include "perl_PL.h"
+#endif
+#endif /*PERL_VERSION*/
+
 #ifdef PERL_OBJECT
 #include <perlhost.h>
 #include "win32iop.h"
@@ -92,6 +118,16 @@ extern "C" {
 #include "http_request.h" 
 #include "util_script.h" 
 #include "http_conf_globals.h"
+#ifdef APACHE_SSL
+#undef _
+#ifdef _config_h_
+#ifdef CAN_PROTOTYPE
+#define _(args) args
+#else
+#define _(args) ()
+#endif
+#endif
+#endif
 #ifdef __cplusplus
 }
 #endif
@@ -339,6 +375,9 @@ if((add->flags & f) || (base->flags & f)) \
 /* some 1.2.x/1.3.x compat stuff */
 /* once 1.3.0 is here, we can toss most of this junk */
 
+#define MMN_130 19980527
+#define APACHE_SSL_12X (defined(APACHE_SSL) && (MODULE_MAGIC_NUMBER < MMN_130))
+
 #if MODULE_MAGIC_NUMBER >= 19980627
 #define MP_CONST_CHAR const char
 #define MP_CONST_ARRAY_HEADER const array_header
