@@ -2,7 +2,7 @@ use strict;
 use Apache::test;
 $|++;
 my $i = 0;
-my $tests = 9;
+my $tests = 4;
 
 my $r = shift;
 $r->send_http_header('text/plain');
@@ -41,30 +41,19 @@ unless($@) {
     $tests += $test_time_parsedate;
 }
 $@ = '';
-
-print "1..$tests\n";
  
-for ("10321", "100666") {
-    my $size = Apache::Util::size_string($_);
-    test ++$i, $size;
-    #print "$_ => $size\n";
-}
-
 my $html = <<EOF;
 <html>
 <head>
 <title>Testing Escape</title>
 </head>
 <body>
-"ok"
-&how
+ok
 </body>
 </html>
 EOF
 
-my $txt = "No html tags in here at all";
-my $etxt = Apache::Util::escape_html($txt);
-test ++$i, $txt eq $etxt;
+print "1..$tests\n";
 
 my $esc = Apache::Util::escape_html($html);
 #print $esc;
@@ -90,8 +79,7 @@ my $Perl = URI::Escape::uri_escape($uri);
 print "C = $C\n";
 print "Perl = $Perl\n";
 
-#test ++$i, lc($C) eq lc($Perl); 
-test ++$i, length($C) && length($Perl); 
+test ++$i, lc($C) eq lc($Perl); 
 
 =pod
 timethese(10000, {
@@ -108,8 +96,7 @@ print "C = $C\n";
 print "Perl = $Perl\n";
 print "builtin = $builtin\n";
 
-#test ++$i, lc($C) eq lc($Perl); 
-test ++$i, length($C) && length($Perl); 
+test ++$i, lc($C) eq lc($Perl); 
 
 =pod
 use Benchmark;
@@ -128,8 +115,7 @@ if($test_date_format) {
 	my $c = Apache::Util::ht_time(time, $fmt, 0);
 	my $p = Date::Format::time2str($fmt, time);
 	print "C=$c\nPerl=$p\n";
-	#test ++$i, $c eq $p;
-        test ++$i, length($c) && length($p);
+	test ++$i, $c eq $p;
     }
 }
 =pod
@@ -184,7 +170,3 @@ Benchmark: timing 10000 iterations of C, Perl...
   C:  1 secs ( 0.42 usr  0.00 sys =  0.42 cpu)
   Perl: 17 secs (16.76 usr  0.07 sys = 16.83 cpu)  
 =cut
-
-my $hash = "aX9eP53k4DGfU";
-test ++$i, Apache::Util::validate_password("dougm", $hash);
-test ++$i, ! Apache::Util::validate_password("mguod", $hash);
